( cd usr/bin ; rm -rf rcs2log )
( cd usr/bin ; ln -sf ../share/cvs/contrib/rcs2log rcs2log )
( cd usr/doc/cvs-1.11.20 ; rm -rf contrib )
( cd usr/doc/cvs-1.11.20 ; ln -sf ../../share/cvs/contrib contrib )
